@@ -4,8 +4,16 @@ import pathlib
 import re
 import shutil
 from contextlib import contextmanager
-from typing import Union, Iterable, Tuple, Optional, Iterator, \
-    Dict, overload, Sequence, Hashable, Any
+from typing import Any
+from typing import Dict
+from typing import Hashable
+from typing import Iterable
+from typing import Iterator
+from typing import Optional
+from typing import Sequence
+from typing import Tuple
+from typing import Union
+from typing import overload
 
 try:
     from typing import Literal  # type: ignore
@@ -13,14 +21,29 @@ except ImportError:
     from typing_extensions import Literal
 
 from paquo import settings
-from paquo._base import QuPathBase
-from paquo._logging import redirect, get_logger
+from paquo._logging import get_logger
+from paquo._logging import redirect
 from paquo._utils import make_backup_filename
 from paquo.classes import QuPathPathClass
-from paquo.images import QuPathProjectImageEntry, ImageProvider, SimpleURIImageProvider, QuPathImageType
-from paquo.java import ImageServerProvider, BufferedImage, ProjectImportImagesCommand, \
-    ProjectIO, File, Projects, String, ServerTools, DefaultProject, URI, GeneralTools, IOException, \
-    NegativeArraySizeException
+from paquo.images import ImageProvider
+from paquo.images import QuPathImageType
+from paquo.images import QuPathProjectImageEntry
+from paquo.images import SimpleURIImageProvider
+from paquo.java import URI
+from paquo.java import BufferedImage
+from paquo.java import DefaultProject
+from paquo.java import ExceptionInInitializerError
+from paquo.java import File
+from paquo.java import Files
+from paquo.java import GeneralTools
+from paquo.java import ImageServerProvider
+from paquo.java import IOException
+from paquo.java import NegativeArraySizeException
+from paquo.java import ProjectImportImagesCommand
+from paquo.java import ProjectIO
+from paquo.java import Projects
+from paquo.java import ServerTools
+from paquo.java import String
 
 _log = get_logger(__name__)
 
@@ -80,7 +103,9 @@ class _ProjectImageEntriesProxy(collections_abc.Sequence):
         return f"ImageEntries({repr([entry.image_name for entry in self])})"
 
     def _repr_html_(self, compact=False) -> str:
-        from paquo._repr import div, h4, repr_html
+        from paquo._repr import div
+        from paquo._repr import h4
+        from paquo._repr import repr_html
         images = [
             repr_html(img, compact=True, index=idx) for idx, img in enumerate(self)
         ]
@@ -150,7 +175,8 @@ ProjectIOMode = Union[
 ]
 
 
-class QuPathProject(QuPathBase[DefaultProject]):
+class QuPathProject:
+    java_object: DefaultProject
 
     def __init__(self,
                  path: Union[str, pathlib.Path],
@@ -213,7 +239,7 @@ class QuPathProject(QuPathBase[DefaultProject]):
             with redirect(stderr=True, stdout=True):
                 project = Projects.createProject(File(str(p_dir)), BufferedImage)
 
-        super().__init__(project)
+        self.java_object = project
         self._image_entries_proxy = _ProjectImageEntriesProxy(self)
         self._image_provider = image_provider
 
@@ -284,6 +310,8 @@ class QuPathProject(QuPathBase[DefaultProject]):
             # is not actually reachable. In that case catch the java IOException
             # and raise a FileNotFoundError here
             raise FileNotFoundError(image_id)
+        except ExceptionInInitializerError:
+            raise IOError("no preferred support found")
         if not support:
             raise IOError("no preferred support found")  # pragma: no cover
         server_builders = list(support.getBuilders())
@@ -324,7 +352,8 @@ class QuPathProject(QuPathBase[DefaultProject]):
         if image_type is not None:
             py_entry.image_type = image_type
         # save project after adding image
-        self.save()
+        py_entry.save()
+        self.save(images=False)
         return py_entry
 
     def is_readable(self) -> Dict[Hashable, bool]:
@@ -337,20 +366,55 @@ class QuPathProject(QuPathBase[DefaultProject]):
             readability_map[image_id] = image.is_readable()
         return readability_map
 
-    def update_image_paths(self, **rebase_kwargs):
-        """update image path uris if image files moved"""
-        # allow rebasing all image uris in a single call to rebase
-        old_uris = [image.uri for image in self.images]
-        new_uris = self._image_provider.rebase(*old_uris, **rebase_kwargs)
+    def update_image_paths(self, *, try_relative: bool = False, **rebase_kwargs) -> None:
+        """update image path uris if image files moved
 
-        # build the java URI to URI mapping
+        Parameters
+        ----------
+        try_relative: bool
+            if try_relative is True, update_image_paths tries to use relative paths
+            to resolve missing image entries. This is useful in case you move the
+            the project together with its images directory, or in case you remount
+            at a different location.
+        **rebase_kwargs:
+            keyword arguments are handed over to the image provider instance.
+            The default image provider is a paquo.images.SimpleURIImageProvider
+            which uses the uri2uri keyword argument. (A mapping from old URI to new
+            URI: Mapping[str, str])
+
+        """
+        if not isinstance(try_relative, bool):
+            raise TypeError(f"try_relative requires bool, got: {type(try_relative).__name__!r}")
+
+        # get the current image URIs
+        old_uris = [image.uri for image in self.images]
+
+        # the uri to uri mapping
         uri2uri = {}
-        for old_uri, new_uri in zip(old_uris, new_uris):
-            if new_uri is None:
-                continue
-            elif ImageProvider.compare_uris(new_uri, old_uri):
-                continue
-            uri2uri[URI(old_uri)] = URI(new_uri)
+
+        if try_relative:
+            assert not rebase_kwargs, "no other kwargs supported when try_relative=True"
+            # test if project was moved (or mounted somewhere else...)
+            prev_pth = GeneralTools.toPath(self.java_object.getPreviousURI()).getParent()
+            proj_pth = GeneralTools.toPath(self.java_object.getURI()).getParent()
+            if prev_pth and proj_pth and not prev_pth.equals(proj_pth):
+                for old_uri in map(URI, old_uris):
+                    img_pth = GeneralTools.toPath(old_uri)
+                    new_pth = proj_pth.resolve(prev_pth.relativize(img_pth)).normalize()
+                    if Files.exists(new_pth):
+                        uri2uri[old_uri] = new_pth.normalize().toUri().normalize()
+
+        else:
+            # allow rebasing all image uris in a single call to rebase
+            new_uris = self._image_provider.rebase(*old_uris, **rebase_kwargs)
+
+            # build the java URI to URI mapping
+            for old_uri, new_uri in zip(old_uris, new_uris):
+                if new_uri is None:
+                    continue
+                elif ImageProvider.compare_uris(new_uri, old_uri):
+                    continue
+                uri2uri[URI(old_uri)] = URI(new_uri)
 
         # update uris if possible
         for image in self.images:
@@ -388,15 +452,16 @@ class QuPathProject(QuPathBase[DefaultProject]):
         return pathlib.Path(str(self.java_object.getPath()))
 
     @redirect(stderr=True, stdout=True)
-    def save(self) -> None:
+    def save(self, images=True) -> None:
         """flush changes in the project to disk
 
         (writes path_classes and project data)
         """
         if self._readonly:
             raise IOError("project in readonly mode")
-        for entry in self.images:
-            entry.save()
+        if images:
+            for entry in self.images:
+                entry.save()
         try:
             self.java_object.syncChanges()
         # convert java land exception
@@ -416,7 +481,12 @@ class QuPathProject(QuPathBase[DefaultProject]):
         return f'{type(self).__name__}(path="{self._path}" mode="{self._mode}")'
 
     def _repr_html_(self) -> str:
-        from paquo._repr import br, h3, div, p, span, repr_html
+        from paquo._repr import br
+        from paquo._repr import div
+        from paquo._repr import h3
+        from paquo._repr import p
+        from paquo._repr import repr_html
+        from paquo._repr import span
         return div(
             h3(style={"margin-top": "0"}, text=f"Project: {self.name}"),
             p(
